package fr.bhprod.sga.entity;

import java.io.File;

import com.jme.bounding.BoundingBox;
import com.jme.bounding.BoundingSphere;
import com.jme.bounding.BoundingVolume;
import com.jme.math.FastMath;
import com.jme.math.Vector3f;
import com.jme.renderer.ColorRGBA;
import com.jme.renderer.Renderer;
import com.jme.scene.Line;
import com.jme.scene.Node;
import com.jme.scene.state.LightState;

import fr.bhprod.sga.terrain.Terrain;
import fr.bhprod.sga.terrain.TerrainPosition;
import fr.bhprod.sga.terrain.TerrainTools;

/**
 * 
 * @author jbeaufils
 * @version 1.0
 */

public class PlayableObject extends DummyObject {
	protected Line selectionShape = null;
	
	public PlayableObject() {
	}
	
	public void destroySelectionShape() {
		selectionShape.removeFromParent();
		selectionShape = null;
	}

	public PlayableObject(String nodeName, Vector3f pos, File xmlModelFile, Renderer renderer) {
		super(nodeName, pos, xmlModelFile, renderer);
	}

	// TODO : Caractristiques : points de vie, ...
	// TODO : Actions possibles
	// TODO : Peut appartenir  une quipe
	
	public void createSelectionShape(Terrain terrain, Node rootNode) {
		BoundingVolume vol = getBoundingBox();

		float radius = 0;

		if (vol.getType() == BoundingVolume.BOUNDING_SPHERE) {
			radius = ((BoundingSphere)vol).radius;
		} else if (vol.getType() == BoundingVolume.BOUNDING_BOX) {
			Vector3f extent = new Vector3f();
			((BoundingBox)vol).getExtent(extent);
			LOGGER.debug("EXTENT = "+extent);
			if (extent.x >= extent.z) {
				radius = extent.x ;
			} else {
				radius = extent.z;
			}
		} else {
			LOGGER.error("BOUNDING VOLUME NOT MANAGED");
			return;
		}
		
		LOGGER.debug("RADIUS = "+radius);
		LOGGER.debug("WORLDTRANSLATION = "+node.getWorldTranslation());

		float delta = FastMath.PI / 12;
		TerrainPosition tp = null;

		Vector3f[] points = new Vector3f[24];
		ColorRGBA[] colors = new ColorRGBA[24];
		
		for (int i = 0; i < 24; i++) {
			tp = TerrainTools.getTerrainPosition(terrain, 
					new Vector3f(node.getWorldTranslation().x + radius * FastMath.cos(delta * i),
							1000,
							node.getWorldTranslation().z + radius * FastMath.sin(delta * i))
						);
			points[i] = new Vector3f(tp.getPosition().x, tp.getPosition().y + 0.001f, tp.getPosition().z);
			colors[i] = new ColorRGBA(0,1,0,1);
		}

		selectionShape = new Line("selection "+node.getName(), points, null, colors, null);
		selectionShape.setMode(Line.LOOP);
		selectionShape.setLineWidth(1);
		selectionShape.setLightCombineMode(LightState.OFF);
		selectionShape.updateRenderState();
		
		rootNode.attachChild(selectionShape);
	}
	
}

