package fr.bhprod.sga.terrain.layer;

import java.io.File;

import com.jme.image.Texture;
import com.jme.renderer.Renderer;
import com.jme.scene.Node;
import com.jme.scene.TriMesh;
import com.jme.util.TextureManager;

import fr.bhprod.sga.config.SgaConstants;
import fr.bhprod.sga.terrain.Terrain;

/**
 * 
 * @author jbeaufils
 * @version 1.0
 */

public final class TextureDetailUtil {

	/**
	 * Create the detail texture layer.
	 * 
	 * @param display
	 *            The current display
	 */
	public static final Node paintManyLayerTextureDetail(Terrain terrain, File[] detailTextureFiles, int[][] detailIndexes, boolean drawInpass, Renderer renderer) {
		Node layerTextureDetailNode = new Node("layerTextureDetail");

		Texture[] detailTextures = new Texture[SgaConstants.DETAIL_FILES.length];
		for (int i = 0; i < detailTextures.length; i++) {
			detailTextures[i] = TextureManager.loadTexture(SgaConstants.DETAIL_FILES[i].getAbsolutePath(), Texture.MM_LINEAR, Texture.FM_LINEAR, 1, true);
			detailTextures[i].setMipmapState(Texture.MM_LINEAR_LINEAR);
			detailTextures[i].setWrap(Texture.WM_WRAP_S_WRAP_T);
		}
		
		// Each patch is 16 X 16 tiles
		for (int tz = 0; tz < terrain.getTilesZ(); tz += 16) {
			for (int tx = 0; tx < terrain.getTilesX(); tx += 16) {
				TriMesh mesh = Patch.createPatch("TextureDetailLayer", 16, tx, tz, detailTextures[detailIndexes[tx/16][tz/16]], false, true, drawInpass, terrain, renderer);
				layerTextureDetailNode.attachChild(mesh);
			}
		}
		
		return layerTextureDetailNode;
	}

	public static final int[] getPatchIndexes(String name) {
		int[] indexes = new int[2];
		indexes[0] = Integer.parseInt(name.substring(name.indexOf("[")+1, name.indexOf("]")));
		indexes[0] = Integer.parseInt(name.substring(name.lastIndexOf("[")+1, name.lastIndexOf("]")));
		return indexes;
	}

}

